@@ -924,8 +924,8 @@ sandbox_init_filter(void)
 
   if (authdir_mode(options)) {
     OPEN_DATADIR("approved-routers");
-    OPEN_CACHEDIR_SUFFIX("my-consensus-microdesc", ".tmp");
-    OPEN_CACHEDIR_SUFFIX("my-consensus-ns", ".tmp");
+    OPEN_DATADIR_SUFFIX("my-consensus-microdesc", ".tmp");
+    OPEN_DATADIR_SUFFIX("my-consensus-ns", ".tmp");
   }
 
   if (options->ServerDNSResolvConfFile)
@@ -1004,6 +1004,11 @@ sandbox_init_filter(void)
   if (options->BridgeAuthoritativeDir)
     RENAME_SUFFIX("networkstatus-bridges", ".tmp");
 
+  if (authdir_mode(options)) {
+    RENAME_SUFFIX("my-consensus-microdesc", ".tmp");
+    RENAME_SUFFIX("my-consensus-ns", ".tmp");
+  }
+
 #define STAT_DATADIR(name)                      \
   sandbox_cfg_allow_stat_filename(&cfg, get_datadir_fname(name))
 
