@@ -42,4 +42,7 @@ typedef struct metrics_gauge_t {
 
 const char *metrics_type_to_str(const metrics_type_t type);
 
+/* Helpers. */
+const char *metrics_format_label(const char *key, const char *value);
+
 #endif /* !defined(TOR_LIB_METRICS_METRICS_COMMON_H) */
