@@ -34,7 +34,8 @@ struct metrics_store_t {
 };
 
 /** Function pointer to the format function of a specific driver. */
-typedef void (fmt_driver_fn_t)(const metrics_store_entry_t *, buf_t *);
+typedef void (fmt_driver_fn_t)(const metrics_store_entry_t *, buf_t *,
+                               bool no_comment);
 
 /** Helper: Free a single entry in a metrics_store_t taking a void pointer
  * parameter. */
@@ -47,6 +48,8 @@ metrics_store_free_void(void *p)
   smartlist_free(list);
 }
 
+#include <stdio.h>
+
 /** Put the given store output in the buffer data and use the format function
  * given in fmt to get it for each entry. */
 static void
@@ -57,8 +60,11 @@ get_output(const metrics_store_t *store, buf_t *data, fmt_driver_fn_t fmt)
   tor_assert(fmt);
 
   STRMAP_FOREACH(store->entries, key, const smartlist_t *, entries) {
+    /* Indicate that we've formatted the comment already for the entries. */
+    bool comment_formatted = false;
     SMARTLIST_FOREACH_BEGIN(entries, const metrics_store_entry_t *, entry) {
-      fmt(entry, data);
+      fmt(entry, data, comment_formatted);
+      comment_formatted = true;
     } SMARTLIST_FOREACH_END(entry);
   } STRMAP_FOREACH_END;
 }
@@ -138,3 +144,14 @@ metrics_store_get_output(const metrics_format_t fmt,
     // LCOV_EXCL_STOP
   }
 }
+
+/** Reset a store as in free its content. */
+void
+metrics_store_reset(metrics_store_t *store)
+{
+  if (store == NULL) {
+    return;
+  }
+  strmap_free(store->entries, metrics_store_free_void);
+  store->entries = strmap_new();
+}
