@@ -826,6 +826,7 @@ test_failed_orconn_tracker(void *arg)
 
   /* Prepare the OR connection that will be used in this test */
   or_connection_t or_conn;
+  memset(&or_conn, 0, sizeof(or_conn));
   tt_int_op(AF_INET,OP_EQ, tor_addr_parse(&or_conn.canonical_orport.addr,
                                           "18.0.0.1"));
   tt_int_op(AF_INET,OP_EQ, tor_addr_parse(&or_conn.base_.addr, "18.0.0.1"));
@@ -992,12 +993,12 @@ test_conn_describe(void *arg)
 
 #define STR(x) #x
 /* where arg is an expression (constant, variable, compound expression) */
-#define CONNECTION_TESTCASE_ARG(name, fork, setup, arg)                 \
-  { #name "_" STR(x),                                                   \
+#define CONNECTION_TESTCASE_ARG(name, extra, fork, setup, arg)          \
+  { STR(name)"/"extra,                                                  \
       test_conn_##name,                                                 \
-      fork,                                                             \
-      &setup,                                                           \
-      (void *)arg }
+      (fork),                                                           \
+      &(setup),                                                         \
+      (void *)(arg) }
 #endif /* !defined(COCCI) */
 
 static const unsigned int PROXY_CONNECT_ARG = PROXY_CONNECT;
@@ -1007,14 +1008,14 @@ struct testcase_t connection_tests[] = {
   CONNECTION_TESTCASE(get_basic, TT_FORK, test_conn_get_basic_st),
   CONNECTION_TESTCASE(get_rsrc,  TT_FORK, test_conn_get_rsrc_st),
 
-  CONNECTION_TESTCASE_ARG(download_status,  TT_FORK,
+  CONNECTION_TESTCASE_ARG(download_status, "microdesc", TT_FORK,
                           test_conn_download_status_st, "microdesc"),
-  CONNECTION_TESTCASE_ARG(download_status,  TT_FORK,
+  CONNECTION_TESTCASE_ARG(download_status, "ns", TT_FORK,
                           test_conn_download_status_st, "ns"),
 
-  CONNECTION_TESTCASE_ARG(https_proxy_connect,   TT_FORK,
+  CONNECTION_TESTCASE_ARG(https_proxy_connect, "https", TT_FORK,
                           test_conn_proxy_connect_st, &PROXY_CONNECT_ARG),
-  CONNECTION_TESTCASE_ARG(haproxy_proxy_connect, TT_FORK,
+  CONNECTION_TESTCASE_ARG(haproxy_proxy_connect, "haproxy", TT_FORK,
                           test_conn_proxy_connect_st, &PROXY_HAPROXY_ARG),
 
   //CONNECTION_TESTCASE(func_suffix, TT_FORK, setup_func_pair),
